==> haskell-ipython-kernel-0.11.0.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-2wbRdvKmXRB2nQIpJ24vIP
key:                  ipython-kernel-0.11.0.0-2wbRdvKmXRB2nQIpJ24vIP
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  57b2cfce4d1fcabd36a3dc2d78c2428e
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-2wbRdvKmXRB2nQIpJ24vIP
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-AhJRgKpvPmBITEZW3Idbwt directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-5ukCxB0doMQ964otfCXv0z text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    uuid-1.3.16-872C2ncsprsByedHsPUft7
    zeromq4-haskell-0.8.0-GqQd4jCMxJNH2nea9dtPe9

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipython-kernel-0.11.0.0-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-9WZAiG2APXu5ZveWI4fTtM
key:                  ipython-kernel-0.11.0.0-9WZAiG2APXu5ZveWI4fTtM
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  6cae4d220eb3f5921568ad16727d9647
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-9WZAiG2APXu5ZveWI4fTtM
depends:
    aeson-2.1.2.1-Ex7WnNUT1auEGSF1Md5zyM base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-7zAI4Osc5DqDSnQ0JPp2cc directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-G7P6lNH75E76cAGC2vHtSc text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-EFINKuAnn2VCsrMAVqSNI6
    uuid-1.3.16-JQKxPD09NZS1Lrau8xh5dp
    zeromq4-haskell-0.8.0-EeNi9eAvIZ8B5xD1S29sDC

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
